Learn R Programming

MGMM (version 1.0.1.3)

FitMVN: Fit Multivariate Normal Distribution

Description

Given a matrix of n x d-dimensional random vectors, possibly containing missing elements, estimates the mean and covariance of the best fitting multivariate normal distribution.

Usage

FitMVN(
  data,
  init_mean = NULL,
  fix_mean = FALSE,
  init_cov = NULL,
  lambda = 0,
  maxit = 100,
  eps = 1e-06,
  report = TRUE
)

Value

An object of class mvn.

Arguments

data

Numeric data matrix.

init_mean

Optional initial mean vector.

fix_mean

Fix the mean to its starting value? Initial values must be provided if TRUE.

init_cov

Optional initial covariance matrix.

lambda

Optional ridge term added to covariance matrix to ensure positive definiteness.

maxit

Maximum number of EM iterations.

eps

Minimum acceptable increment in the EM objective.

report

Report fitting progress?