Given a matrix of n x d-dimensional random vectors, possibly containing missing elements, estimates the mean and covariance of the best fitting multivariate normal distribution.
FitMVN(
data,
init_mean = NULL,
fix_mean = FALSE,
init_cov = NULL,
lambda = 0,
maxit = 100,
eps = 1e-06,
report = TRUE
)An object of class mvn.
Numeric data matrix.
Optional initial mean vector.
Fix the mean to its starting value? Initial values must be
provided if TRUE.
Optional initial covariance matrix.
Optional ridge term added to covariance matrix to ensure positive definiteness.
Maximum number of EM iterations.
Minimum acceptable increment in the EM objective.
Report fitting progress?