View source: R/04_Partition_Data.R
| ReconstituteData | R Documentation |
Reassembles a data matrix from the list returned by PartitionData,
restoring the original row order and dimension names.
ReconstituteData(split_data)
split_data |
List returned by |
Numeric matrix with the same dimensions and row order as the
original data passed to PartitionData.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.